<a id="mypy-boto3-pinpoint"></a>

# mypy-boto3-pinpoint

[![PyPI - mypy-boto3-pinpoint](https://img.shields.io/pypi/v/mypy-boto3-pinpoint.svg?color=blue)](https://pypi.org/project/mypy-boto3-pinpoint)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-pinpoint.svg?color=blue)](https://pypi.org/project/mypy-boto3-pinpoint)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-pinpoint?color=blue)](https://pypistats.org/packages/mypy-boto3-pinpoint)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Pinpoint 1.19.11](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/pinpoint.html#Pinpoint)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.1.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-pinpoint docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_pinpoint/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-pinpoint](#mypy-boto3-pinpoint)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Pinpoint` service.

```bash
python -m pip install boto3-stubs[pinpoint]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[pinpoint]` in your environment:
  `python -m pip install 'boto3-stubs[pinpoint]'`

Both type checking and auto-complete should work for `Pinpoint` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[pinpoint]` in your environment:
  `python -m pip install 'boto3-stubs[pinpoint]'`

Both type checking and auto-complete should work for `Pinpoint` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[pinpoint]` in your environment:
  `python -m pip install 'boto3-stubs[pinpoint]'`
- Run `mypy` as usual

Type checking should work for `Pinpoint` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[pinpoint]` in your environment:
  `python -m pip install 'boto3-stubs[pinpoint]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Pinpoint` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`PinpointClient` provides annotations for `boto3.client("pinpoint")`.

```python
import boto3

from mypy_boto3_pinpoint import PinpointClient

client: PinpointClient = boto3.client("pinpoint")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: PinpointClient = session.client("pinpoint")
```

<a id="literals"></a>

### Literals

`mypy_boto3_pinpoint.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_pinpoint.literals import (
    ActionType,
    AlignmentType,
    AttributeTypeType,
    ButtonActionType,
    CampaignStatusType,
    ChannelTypeType,
    DeliveryStatusType,
    DimensionTypeType,
    DurationType,
    EndpointTypesElementType,
    FilterTypeType,
    FormatType,
    FrequencyType,
    IncludeType,
    JobStatusType,
    LayoutType,
    MessageTypeType,
    ModeType,
    OperatorType,
    RecencyTypeType,
    SegmentTypeType,
    SourceTypeType,
    StateType,
    TemplateTypeType,
    TypeType,
    ServiceName,
)

def check_value(value: ActionType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_pinpoint.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_pinpoint.type_defs import (
    ADMChannelRequestTypeDef,
    ADMChannelResponseTypeDef,
    ADMMessageTypeDef,
    APNSChannelRequestTypeDef,
    APNSChannelResponseTypeDef,
    APNSMessageTypeDef,
    APNSPushNotificationTemplateTypeDef,
    APNSSandboxChannelRequestTypeDef,
    APNSSandboxChannelResponseTypeDef,
    APNSVoipChannelRequestTypeDef,
    APNSVoipChannelResponseTypeDef,
    APNSVoipSandboxChannelRequestTypeDef,
    APNSVoipSandboxChannelResponseTypeDef,
    ActivitiesResponseTypeDef,
    ActivityResponseTypeDef,
    ActivityTypeDef,
    AddressConfigurationTypeDef,
    AndroidPushNotificationTemplateTypeDef,
    ApplicationDateRangeKpiResponseTypeDef,
    ApplicationResponseTypeDef,
    ApplicationSettingsResourceTypeDef,
    ApplicationsResponseTypeDef,
    AttributeDimensionTypeDef,
    AttributesResourceTypeDef,
    BaiduChannelRequestTypeDef,
    BaiduChannelResponseTypeDef,
    BaiduMessageTypeDef,
    BaseKpiResultTypeDef,
    CampaignCustomMessageTypeDef,
    CampaignDateRangeKpiResponseTypeDef,
    CampaignEmailMessageTypeDef,
    CampaignEventFilterTypeDef,
    CampaignHookTypeDef,
    CampaignInAppMessageTypeDef,
    CampaignLimitsTypeDef,
    CampaignResponseTypeDef,
    CampaignSmsMessageTypeDef,
    CampaignStateTypeDef,
    CampaignsResponseTypeDef,
    ChannelResponseTypeDef,
    ChannelsResponseTypeDef,
    ConditionTypeDef,
    ConditionalSplitActivityTypeDef,
    ContactCenterActivityTypeDef,
    CreateAppRequestRequestTypeDef,
    CreateAppResponseTypeDef,
    CreateApplicationRequestTypeDef,
    CreateCampaignRequestRequestTypeDef,
    CreateCampaignResponseTypeDef,
    CreateEmailTemplateRequestRequestTypeDef,
    CreateEmailTemplateResponseTypeDef,
    CreateExportJobRequestRequestTypeDef,
    CreateExportJobResponseTypeDef,
    CreateImportJobRequestRequestTypeDef,
    CreateImportJobResponseTypeDef,
    CreateInAppTemplateRequestRequestTypeDef,
    CreateInAppTemplateResponseTypeDef,
    CreateJourneyRequestRequestTypeDef,
    CreateJourneyResponseTypeDef,
    CreatePushTemplateRequestRequestTypeDef,
    CreatePushTemplateResponseTypeDef,
    CreateRecommenderConfigurationRequestRequestTypeDef,
    CreateRecommenderConfigurationResponseTypeDef,
    CreateRecommenderConfigurationTypeDef,
    CreateSegmentRequestRequestTypeDef,
    CreateSegmentResponseTypeDef,
    CreateSmsTemplateRequestRequestTypeDef,
    CreateSmsTemplateResponseTypeDef,
    CreateTemplateMessageBodyTypeDef,
    CreateVoiceTemplateRequestRequestTypeDef,
    CreateVoiceTemplateResponseTypeDef,
    CustomDeliveryConfigurationTypeDef,
    CustomMessageActivityTypeDef,
    DefaultButtonConfigurationTypeDef,
    DefaultMessageTypeDef,
    DefaultPushNotificationMessageTypeDef,
    DefaultPushNotificationTemplateTypeDef,
    DeleteAdmChannelRequestRequestTypeDef,
    DeleteAdmChannelResponseTypeDef,
    DeleteApnsChannelRequestRequestTypeDef,
    DeleteApnsChannelResponseTypeDef,
    DeleteApnsSandboxChannelRequestRequestTypeDef,
    DeleteApnsSandboxChannelResponseTypeDef,
    DeleteApnsVoipChannelRequestRequestTypeDef,
    DeleteApnsVoipChannelResponseTypeDef,
    DeleteApnsVoipSandboxChannelRequestRequestTypeDef,
    DeleteApnsVoipSandboxChannelResponseTypeDef,
    DeleteAppRequestRequestTypeDef,
    DeleteAppResponseTypeDef,
    DeleteBaiduChannelRequestRequestTypeDef,
    DeleteBaiduChannelResponseTypeDef,
    DeleteCampaignRequestRequestTypeDef,
    DeleteCampaignResponseTypeDef,
    DeleteEmailChannelRequestRequestTypeDef,
    DeleteEmailChannelResponseTypeDef,
    DeleteEmailTemplateRequestRequestTypeDef,
    DeleteEmailTemplateResponseTypeDef,
    DeleteEndpointRequestRequestTypeDef,
    DeleteEndpointResponseTypeDef,
    DeleteEventStreamRequestRequestTypeDef,
    DeleteEventStreamResponseTypeDef,
    DeleteGcmChannelRequestRequestTypeDef,
    DeleteGcmChannelResponseTypeDef,
    DeleteInAppTemplateRequestRequestTypeDef,
    DeleteInAppTemplateResponseTypeDef,
    DeleteJourneyRequestRequestTypeDef,
    DeleteJourneyResponseTypeDef,
    DeletePushTemplateRequestRequestTypeDef,
    DeletePushTemplateResponseTypeDef,
    DeleteRecommenderConfigurationRequestRequestTypeDef,
    DeleteRecommenderConfigurationResponseTypeDef,
    DeleteSegmentRequestRequestTypeDef,
    DeleteSegmentResponseTypeDef,
    DeleteSmsChannelRequestRequestTypeDef,
    DeleteSmsChannelResponseTypeDef,
    DeleteSmsTemplateRequestRequestTypeDef,
    DeleteSmsTemplateResponseTypeDef,
    DeleteUserEndpointsRequestRequestTypeDef,
    DeleteUserEndpointsResponseTypeDef,
    DeleteVoiceChannelRequestRequestTypeDef,
    DeleteVoiceChannelResponseTypeDef,
    DeleteVoiceTemplateRequestRequestTypeDef,
    DeleteVoiceTemplateResponseTypeDef,
    DirectMessageConfigurationTypeDef,
    EmailChannelRequestTypeDef,
    EmailChannelResponseTypeDef,
    EmailMessageActivityTypeDef,
    EmailMessageTypeDef,
    EmailTemplateRequestTypeDef,
    EmailTemplateResponseTypeDef,
    EndpointBatchItemTypeDef,
    EndpointBatchRequestTypeDef,
    EndpointDemographicTypeDef,
    EndpointItemResponseTypeDef,
    EndpointLocationTypeDef,
    EndpointMessageResultTypeDef,
    EndpointRequestTypeDef,
    EndpointResponseTypeDef,
    EndpointSendConfigurationTypeDef,
    EndpointUserTypeDef,
    EndpointsResponseTypeDef,
    EventConditionTypeDef,
    EventDimensionsTypeDef,
    EventFilterTypeDef,
    EventItemResponseTypeDef,
    EventStartConditionTypeDef,
    EventStreamTypeDef,
    EventTypeDef,
    EventsBatchTypeDef,
    EventsRequestTypeDef,
    EventsResponseTypeDef,
    ExportJobRequestTypeDef,
    ExportJobResourceTypeDef,
    ExportJobResponseTypeDef,
    ExportJobsResponseTypeDef,
    GCMChannelRequestTypeDef,
    GCMChannelResponseTypeDef,
    GCMMessageTypeDef,
    GPSCoordinatesTypeDef,
    GPSPointDimensionTypeDef,
    GetAdmChannelRequestRequestTypeDef,
    GetAdmChannelResponseTypeDef,
    GetApnsChannelRequestRequestTypeDef,
    GetApnsChannelResponseTypeDef,
    GetApnsSandboxChannelRequestRequestTypeDef,
    GetApnsSandboxChannelResponseTypeDef,
    GetApnsVoipChannelRequestRequestTypeDef,
    GetApnsVoipChannelResponseTypeDef,
    GetApnsVoipSandboxChannelRequestRequestTypeDef,
    GetApnsVoipSandboxChannelResponseTypeDef,
    GetAppRequestRequestTypeDef,
    GetAppResponseTypeDef,
    GetApplicationDateRangeKpiRequestRequestTypeDef,
    GetApplicationDateRangeKpiResponseTypeDef,
    GetApplicationSettingsRequestRequestTypeDef,
    GetApplicationSettingsResponseTypeDef,
    GetAppsRequestRequestTypeDef,
    GetAppsResponseTypeDef,
    GetBaiduChannelRequestRequestTypeDef,
    GetBaiduChannelResponseTypeDef,
    GetCampaignActivitiesRequestRequestTypeDef,
    GetCampaignActivitiesResponseTypeDef,
    GetCampaignDateRangeKpiRequestRequestTypeDef,
    GetCampaignDateRangeKpiResponseTypeDef,
    GetCampaignRequestRequestTypeDef,
    GetCampaignResponseTypeDef,
    GetCampaignVersionRequestRequestTypeDef,
    GetCampaignVersionResponseTypeDef,
    GetCampaignVersionsRequestRequestTypeDef,
    GetCampaignVersionsResponseTypeDef,
    GetCampaignsRequestRequestTypeDef,
    GetCampaignsResponseTypeDef,
    GetChannelsRequestRequestTypeDef,
    GetChannelsResponseTypeDef,
    GetEmailChannelRequestRequestTypeDef,
    GetEmailChannelResponseTypeDef,
    GetEmailTemplateRequestRequestTypeDef,
    GetEmailTemplateResponseTypeDef,
    GetEndpointRequestRequestTypeDef,
    GetEndpointResponseTypeDef,
    GetEventStreamRequestRequestTypeDef,
    GetEventStreamResponseTypeDef,
    GetExportJobRequestRequestTypeDef,
    GetExportJobResponseTypeDef,
    GetExportJobsRequestRequestTypeDef,
    GetExportJobsResponseTypeDef,
    GetGcmChannelRequestRequestTypeDef,
    GetGcmChannelResponseTypeDef,
    GetImportJobRequestRequestTypeDef,
    GetImportJobResponseTypeDef,
    GetImportJobsRequestRequestTypeDef,
    GetImportJobsResponseTypeDef,
    GetInAppMessagesRequestRequestTypeDef,
    GetInAppMessagesResponseTypeDef,
    GetInAppTemplateRequestRequestTypeDef,
    GetInAppTemplateResponseTypeDef,
    GetJourneyDateRangeKpiRequestRequestTypeDef,
    GetJourneyDateRangeKpiResponseTypeDef,
    GetJourneyExecutionActivityMetricsRequestRequestTypeDef,
    GetJourneyExecutionActivityMetricsResponseTypeDef,
    GetJourneyExecutionMetricsRequestRequestTypeDef,
    GetJourneyExecutionMetricsResponseTypeDef,
    GetJourneyRequestRequestTypeDef,
    GetJourneyResponseTypeDef,
    GetPushTemplateRequestRequestTypeDef,
    GetPushTemplateResponseTypeDef,
    GetRecommenderConfigurationRequestRequestTypeDef,
    GetRecommenderConfigurationResponseTypeDef,
    GetRecommenderConfigurationsRequestRequestTypeDef,
    GetRecommenderConfigurationsResponseTypeDef,
    GetSegmentExportJobsRequestRequestTypeDef,
    GetSegmentExportJobsResponseTypeDef,
    GetSegmentImportJobsRequestRequestTypeDef,
    GetSegmentImportJobsResponseTypeDef,
    GetSegmentRequestRequestTypeDef,
    GetSegmentResponseTypeDef,
    GetSegmentVersionRequestRequestTypeDef,
    GetSegmentVersionResponseTypeDef,
    GetSegmentVersionsRequestRequestTypeDef,
    GetSegmentVersionsResponseTypeDef,
    GetSegmentsRequestRequestTypeDef,
    GetSegmentsResponseTypeDef,
    GetSmsChannelRequestRequestTypeDef,
    GetSmsChannelResponseTypeDef,
    GetSmsTemplateRequestRequestTypeDef,
    GetSmsTemplateResponseTypeDef,
    GetUserEndpointsRequestRequestTypeDef,
    GetUserEndpointsResponseTypeDef,
    GetVoiceChannelRequestRequestTypeDef,
    GetVoiceChannelResponseTypeDef,
    GetVoiceTemplateRequestRequestTypeDef,
    GetVoiceTemplateResponseTypeDef,
    HoldoutActivityTypeDef,
    ImportJobRequestTypeDef,
    ImportJobResourceTypeDef,
    ImportJobResponseTypeDef,
    ImportJobsResponseTypeDef,
    InAppCampaignScheduleTypeDef,
    InAppMessageBodyConfigTypeDef,
    InAppMessageButtonTypeDef,
    InAppMessageCampaignTypeDef,
    InAppMessageContentTypeDef,
    InAppMessageHeaderConfigTypeDef,
    InAppMessageTypeDef,
    InAppMessagesResponseTypeDef,
    InAppTemplateRequestTypeDef,
    InAppTemplateResponseTypeDef,
    ItemResponseTypeDef,
    JourneyChannelSettingsTypeDef,
    JourneyCustomMessageTypeDef,
    JourneyDateRangeKpiResponseTypeDef,
    JourneyEmailMessageTypeDef,
    JourneyExecutionActivityMetricsResponseTypeDef,
    JourneyExecutionMetricsResponseTypeDef,
    JourneyLimitsTypeDef,
    JourneyPushMessageTypeDef,
    JourneyResponseTypeDef,
    JourneySMSMessageTypeDef,
    JourneyScheduleTypeDef,
    JourneyStateRequestTypeDef,
    JourneysResponseTypeDef,
    ListJourneysRequestRequestTypeDef,
    ListJourneysResponseTypeDef,
    ListRecommenderConfigurationsResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTemplateVersionsRequestRequestTypeDef,
    ListTemplateVersionsResponseTypeDef,
    ListTemplatesRequestRequestTypeDef,
    ListTemplatesResponseTypeDef,
    MessageBodyTypeDef,
    MessageConfigurationTypeDef,
    MessageRequestTypeDef,
    MessageResponseTypeDef,
    MessageResultTypeDef,
    MessageTypeDef,
    MetricDimensionTypeDef,
    MultiConditionalBranchTypeDef,
    MultiConditionalSplitActivityTypeDef,
    NumberValidateRequestTypeDef,
    NumberValidateResponseTypeDef,
    OverrideButtonConfigurationTypeDef,
    PhoneNumberValidateRequestRequestTypeDef,
    PhoneNumberValidateResponseTypeDef,
    PublicEndpointTypeDef,
    PushMessageActivityTypeDef,
    PushNotificationTemplateRequestTypeDef,
    PushNotificationTemplateResponseTypeDef,
    PutEventStreamRequestRequestTypeDef,
    PutEventStreamResponseTypeDef,
    PutEventsRequestRequestTypeDef,
    PutEventsResponseTypeDef,
    QuietTimeTypeDef,
    RandomSplitActivityTypeDef,
    RandomSplitEntryTypeDef,
    RawEmailTypeDef,
    RecencyDimensionTypeDef,
    RecommenderConfigurationResponseTypeDef,
    RemoveAttributesRequestRequestTypeDef,
    RemoveAttributesResponseTypeDef,
    ResponseMetadataTypeDef,
    ResultRowTypeDef,
    ResultRowValueTypeDef,
    SMSChannelRequestTypeDef,
    SMSChannelResponseTypeDef,
    SMSMessageActivityTypeDef,
    SMSMessageTypeDef,
    SMSTemplateRequestTypeDef,
    SMSTemplateResponseTypeDef,
    ScheduleTypeDef,
    SegmentBehaviorsTypeDef,
    SegmentConditionTypeDef,
    SegmentDemographicsTypeDef,
    SegmentDimensionsTypeDef,
    SegmentGroupListTypeDef,
    SegmentGroupTypeDef,
    SegmentImportResourceTypeDef,
    SegmentLocationTypeDef,
    SegmentReferenceTypeDef,
    SegmentResponseTypeDef,
    SegmentsResponseTypeDef,
    SendMessagesRequestRequestTypeDef,
    SendMessagesResponseTypeDef,
    SendUsersMessageRequestTypeDef,
    SendUsersMessageResponseTypeDef,
    SendUsersMessagesRequestRequestTypeDef,
    SendUsersMessagesResponseTypeDef,
    SessionTypeDef,
    SetDimensionTypeDef,
    SimpleConditionTypeDef,
    SimpleEmailPartTypeDef,
    SimpleEmailTypeDef,
    StartConditionTypeDef,
    TagResourceRequestRequestTypeDef,
    TagsModelTypeDef,
    TemplateActiveVersionRequestTypeDef,
    TemplateConfigurationTypeDef,
    TemplateCreateMessageBodyTypeDef,
    TemplateResponseTypeDef,
    TemplateTypeDef,
    TemplateVersionResponseTypeDef,
    TemplateVersionsResponseTypeDef,
    TemplatesResponseTypeDef,
    TreatmentResourceTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateAdmChannelRequestRequestTypeDef,
    UpdateAdmChannelResponseTypeDef,
    UpdateApnsChannelRequestRequestTypeDef,
    UpdateApnsChannelResponseTypeDef,
    UpdateApnsSandboxChannelRequestRequestTypeDef,
    UpdateApnsSandboxChannelResponseTypeDef,
    UpdateApnsVoipChannelRequestRequestTypeDef,
    UpdateApnsVoipChannelResponseTypeDef,
    UpdateApnsVoipSandboxChannelRequestRequestTypeDef,
    UpdateApnsVoipSandboxChannelResponseTypeDef,
    UpdateApplicationSettingsRequestRequestTypeDef,
    UpdateApplicationSettingsResponseTypeDef,
    UpdateAttributesRequestTypeDef,
    UpdateBaiduChannelRequestRequestTypeDef,
    UpdateBaiduChannelResponseTypeDef,
    UpdateCampaignRequestRequestTypeDef,
    UpdateCampaignResponseTypeDef,
    UpdateEmailChannelRequestRequestTypeDef,
    UpdateEmailChannelResponseTypeDef,
    UpdateEmailTemplateRequestRequestTypeDef,
    UpdateEmailTemplateResponseTypeDef,
    UpdateEndpointRequestRequestTypeDef,
    UpdateEndpointResponseTypeDef,
    UpdateEndpointsBatchRequestRequestTypeDef,
    UpdateEndpointsBatchResponseTypeDef,
    UpdateGcmChannelRequestRequestTypeDef,
    UpdateGcmChannelResponseTypeDef,
    UpdateInAppTemplateRequestRequestTypeDef,
    UpdateInAppTemplateResponseTypeDef,
    UpdateJourneyRequestRequestTypeDef,
    UpdateJourneyResponseTypeDef,
    UpdateJourneyStateRequestRequestTypeDef,
    UpdateJourneyStateResponseTypeDef,
    UpdatePushTemplateRequestRequestTypeDef,
    UpdatePushTemplateResponseTypeDef,
    UpdateRecommenderConfigurationRequestRequestTypeDef,
    UpdateRecommenderConfigurationResponseTypeDef,
    UpdateRecommenderConfigurationTypeDef,
    UpdateSegmentRequestRequestTypeDef,
    UpdateSegmentResponseTypeDef,
    UpdateSmsChannelRequestRequestTypeDef,
    UpdateSmsChannelResponseTypeDef,
    UpdateSmsTemplateRequestRequestTypeDef,
    UpdateSmsTemplateResponseTypeDef,
    UpdateTemplateActiveVersionRequestRequestTypeDef,
    UpdateTemplateActiveVersionResponseTypeDef,
    UpdateVoiceChannelRequestRequestTypeDef,
    UpdateVoiceChannelResponseTypeDef,
    UpdateVoiceTemplateRequestRequestTypeDef,
    UpdateVoiceTemplateResponseTypeDef,
    VoiceChannelRequestTypeDef,
    VoiceChannelResponseTypeDef,
    VoiceMessageTypeDef,
    VoiceTemplateRequestTypeDef,
    VoiceTemplateResponseTypeDef,
    WaitActivityTypeDef,
    WaitTimeTypeDef,
    WriteApplicationSettingsRequestTypeDef,
    WriteCampaignRequestTypeDef,
    WriteEventStreamTypeDef,
    WriteJourneyRequestTypeDef,
    WriteSegmentRequestTypeDef,
    WriteTreatmentResourceTypeDef,
)

def get_structure() -> ADMChannelRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-pinpoint` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-pinpoint docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_pinpoint/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
